@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2010 Maxime DOYEN
+ *	Copyright (C) 1995-2013 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -17,7 +17,14 @@
  *	along with this program.	If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef __HB_QIF__H__
+#define __HB_QIF__H__
+
 typedef struct _QifContext QifContext;
+typedef struct _qif_split	QIFSplit;
+typedef struct _qif_tran	QIF_Tran;
+
+
 struct _QifContext
 {
 	GList *q_acc;
@@ -27,19 +34,26 @@ struct _QifContext
 
 };
 
+struct _qif_split
+{
+	gchar		*category;
+	gdouble		amount;
+	gchar		*memo;
+};
 
-
-typedef struct _qif_tran	QIF_Tran;
 struct _qif_tran
 {
+	gchar		*account;
 	gchar		*date;
 	gdouble		amount;
-	gboolean	validated;
+	gboolean	reconciled;
 	gchar		*info;
 	gchar		*payee;
 	gchar		*memo;
 	gchar		*category;
-	gchar		*account;
+
+	gint		nb_splits;
+	QIFSplit	splits[TXN_MAX_SPLIT];
 };
 
 
@@ -58,8 +72,9 @@ enum QIF_Type
 
 
 GList *account_import_qif(gchar *filename, ImportContext *ictx);
-gdouble
-hb_qif_parser_get_amount(gchar *string);
+gdouble hb_qif_parser_get_amount(gchar *string);
 
 void test_qif_export (void);
 
+
+#endif
\ No newline at end of file
