@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2013 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -29,6 +29,7 @@ enum
 {
 	PAGE_INTRO,
 	PAGE_FILE,
+	PAGE_RESULT,
 	PAGE_OPTIONS,
 	PAGE_CONFIRM,
 	NUM_PAGE
@@ -44,7 +45,10 @@ struct _ImportContext
 	gint		cnt_new_ope;
 	gint		cnt_new_pay;
 	gint		cnt_new_cat;
+	gint		datefmt;
 	const gchar		*encoding;
+	gint		cnt_err_date;
+	gint		nb_duplicate;
 };
 
 
@@ -63,6 +67,8 @@ struct import_data
 	GtkWidget	*assistant;
 	GtkWidget	*pages[NUM_PAGE];
 
+	GtkWidget	*GR_page;
+	
 	GdkPixbuf	*head_pixbuf;
 	GdkPixbuf	*side_pixbuf;
 	
@@ -71,12 +77,20 @@ struct import_data
 	GtkWidget	*ok_image;
 	GtkWidget	*ko_image;
 
+	GtkWidget	*TX_filepath;
 	GtkWidget	*TX_filename;
+	GtkWidget	*TX_encoding;
 	GtkWidget	*TX_filedetails;
 
+	GtkWidget	*GR_error;
+	GtkWidget   *GR_options;
+	GtkWidget   *GR_duplicate;
+
 //	GtkWidget	*LA_acc;
 	GtkWidget	*NB_decay;
 
+	GtkWidget	*BT_refresh;
+	GtkWidget	*CY_dateorder;
 
 	GtkWidget	*LV_acc;
 	GtkWidget	*BT_edit;
@@ -90,7 +104,7 @@ struct import_data
 	GtkWidget	*TX_trn_nop;
 	GtkWidget	*TX_trn_asg;
 
-	
+	gchar		*filepath;
 	gchar		*filename;
 	guint		filetype;
 
@@ -118,7 +132,7 @@ struct import_target_data
 };
 
 
-GtkWidget *create_import_window (void);
+GtkWidget *ui_import_window_new (void);
 Account *import_create_account(gchar *name, gchar *number);
 const gchar *homebank_file_getencoding(gchar *filename);
 gchar *homebank_utf8_ensure(gchar *buffer);
