@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2011 Maxime DOYEN
+ *  Copyright (C) 1995-2013 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -19,7 +19,6 @@
 
 
 #include "homebank.h"
-#include "preferences.h"
 
 #include "list_account.h"
 
@@ -78,6 +77,7 @@ gint dt;
 /*
 ** draw some text from the stored data structure
 */
+/*
 static void
 acc_type_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
@@ -96,7 +96,7 @@ gint dt;
 	else
 		g_object_set(renderer, "text", NULL, NULL);
 }
-
+*/
 
 /*
 ** draw some text from the stored data structure
@@ -118,15 +118,12 @@ gchar *groupname;
 		LST_DSPACC_NAME, &groupname,
 		-1);
 
-	DB( g_print("acc %x\n", acc) );
-
-
 	if( dt == DSPACC_TYPE_NORMAL )
 	{
 		switch(GPOINTER_TO_INT(user_data))
 		{
 			case 1:
-				g_object_set(renderer, "text", acc->name, NULL);
+				g_object_set(renderer, "weight", PANGO_WEIGHT_NORMAL, "text", acc->name, NULL);
 				break;
 			case 2:
 				//g_object_set(renderer, "text", acc->number, NULL);
@@ -135,7 +132,10 @@ gchar *groupname;
 		}
 	}
 	else
-		g_object_set(renderer, "markup", groupname, NULL);
+		g_object_set(renderer,
+		    "weight", PANGO_WEIGHT_BOLD,
+		    "text", groupname, 
+		    NULL);
 }
 
 static void
@@ -144,7 +144,6 @@ float_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, Gtk
 gdouble value;
 gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 Account *acc;
-//guint32 kcur;
 gint dt;
 gint weight;
 gchar *color;
@@ -155,14 +154,51 @@ gchar *color;
 		GPOINTER_TO_INT(user_data), &value,		//LST_DSPACC_(BANK/TODAY/FUTURE)
 		-1);
 
-
 	if( dt == DSPACC_TYPE_HEADER )
-		g_object_set(renderer, "markup", NULL, NULL);
+	{
+	gboolean expanded;
+	GtkTreePath* tp;
+
+		tp = gtk_tree_model_get_path(model, iter);
+		expanded = gtk_tree_view_row_expanded(GTK_TREE_VIEW(gtk_tree_view_column_get_tree_view(col)), tp);
+	
+		if(!expanded)
+		{
+			//hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->kcur);
+			mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
+			color = get_normal_color_amount(value);
+			g_object_set(renderer,
+			    "weight", PANGO_WEIGHT_NORMAL,
+				"foreground",  color,
+			    "text", buf, 
+		    NULL);
+		}
+		else
+			g_object_set(renderer, "text", NULL, 
+		    NULL);
+			
+		
+	}
 	else
 	{
+		// prevent errors
 		//kcur = acc != NULL ? acc->kcur : GLOBALS->kcur;
 
-		//mystrfmoncurr(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, kcur);
+		//original
+		//mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
+
+		//base test
+		/*
+		if(kcur != GLOBALS->kcur)
+		{
+			gdouble newval = amount_base_amount(value, kcur);
+			//g_print("currency=%d :: value='%.2f' newvalue='%.2f'\n", kcur, value, newval);
+			value = newval;
+			mystrfmoncurr(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->kcur);
+		}
+		else*/
+		
+		//hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, kcur);
 		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
 		
 		color = NULL;
@@ -178,6 +214,8 @@ gchar *color;
 			weight = PANGO_WEIGHT_BOLD;
 		}
 
+		//g_print("value='%.2f' buf='%s' color='%s'\n", value, buf, color);
+		
 		g_object_set(renderer, 
 			"weight", weight,
 			"foreground",  color,
@@ -215,15 +253,29 @@ list_account_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b,
 gint result = 0;
 gint dt1, dt2;
 Account *entry1, *entry2;
+//gchar *name1, *name2;
 
-    gtk_tree_model_get(model, a, LST_DSPACC_DATATYPE, &dt1, LST_DSPACC_DATAS, &entry1, -1);
-    gtk_tree_model_get(model, b, LST_DSPACC_DATATYPE, &dt2, LST_DSPACC_DATAS, &entry2, -1);
+    gtk_tree_model_get(model, a, 
+    	LST_DSPACC_DATATYPE, &dt1, 
+    	LST_DSPACC_DATAS, &entry1,
+    	//LST_DSPACC_NAME, &name1,
+    	-1);
+    gtk_tree_model_get(model, b, 
+    	LST_DSPACC_DATATYPE, &dt2, 
+    	LST_DSPACC_DATAS, &entry2,
+    	//LST_DSPACC_NAME, &name2,
+    	-1);
 
 	if( dt1 == DSPACC_TYPE_NORMAL && dt2 == DSPACC_TYPE_NORMAL )
 	{
 		result = entry1->pos - entry2->pos;
 	}
 
+/*	if( dt1 == DSPACC_TYPE_HEADER && dt2 == DSPACC_TYPE_HEADER )
+	{
+		result = g_utf8_collate(name1, name2);
+	}*/
+
     return result;
 }
 
@@ -268,9 +320,8 @@ GtkTreeViewColumn  *column;
 	  	NUM_LST_DSPACC,
 		G_TYPE_POINTER,
 		G_TYPE_INT,		/* datatype */
-		G_TYPE_INT,		/* fake: state */
+		G_TYPE_INT,		/* fake: status */
 		G_TYPE_STRING,	/* fake: name */
-		G_TYPE_INT,		/* fake: type */
 		G_TYPE_DOUBLE,
 		G_TYPE_DOUBLE,
 		G_TYPE_DOUBLE
@@ -286,46 +337,9 @@ GtkTreeViewColumn  *column;
 
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_SINGLE);
 
-
-	/* Account */
+    /* Status */
 	column = gtk_tree_view_column_new();
-
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
-    gtk_tree_view_column_pack_start(column, renderer, FALSE);
-    gtk_tree_view_column_set_cell_data_func(column, renderer, status_cell_data_function, GINT_TO_POINTER(1), NULL);
-
-    renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
-    gtk_tree_view_column_pack_start(column, renderer, FALSE);
-    gtk_tree_view_column_set_cell_data_func(column, renderer, status_cell_data_function, GINT_TO_POINTER(2), NULL);
-
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, text_cell_data_function, GINT_TO_POINTER(1), NULL);
-	gtk_tree_view_column_set_resizable(column, TRUE);
-	gtk_tree_view_column_set_alignment (column, 0.5);
-
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-
-	gtk_tree_view_set_expander_column(GTK_TREE_VIEW (view), column);
-
-	/* Type */
-	column = gtk_tree_view_column_new();
-    gtk_tree_view_column_set_title(column, _("Type"));
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, acc_type_cell_data_function, NULL, NULL);
-	gtk_tree_view_column_set_resizable(column, TRUE);
-	gtk_tree_view_column_set_alignment (column, 0.5);
-
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-
-
-    /* State */
-/*
-	column = gtk_tree_view_column_new();
-    gtk_tree_view_column_set_title(column, _("State"));
+    gtk_tree_view_column_set_title(column, _("Status"));
 
     renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
@@ -339,7 +353,24 @@ GtkTreeViewColumn  *column;
 
 	gtk_tree_view_column_set_alignment (column, 0.5);
     gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-*/
+
+	/* Account */
+	column = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_title(column, _("Accounts"));
+	
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, text_cell_data_function, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_alignment (column, 0.5);
+
+	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+
+	gtk_tree_view_set_expander_column(GTK_TREE_VIEW (view), column);
+
+
+
+
 
     /* Bank */
 	column = amount_list_account_column(_("Bank"), LST_DSPACC_BANK);
