@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2013 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -30,14 +30,13 @@ enum
 };
 
 
-/* list display account (wallet) */
+/* list display account */
 enum
 {
 	LST_DSPACC_DATAS,
 	LST_DSPACC_DATATYPE,
 	LST_DSPACC_STATE,	/* fake column */
 	LST_DSPACC_NAME,	/* fake column */
-	LST_DSPACC_TYPE,	/* fake column */
 	LST_DSPACC_BANK,
 	LST_DSPACC_TODAY,
 	LST_DSPACC_FUTURE,
@@ -47,4 +46,4 @@ enum
 
 GtkWidget *create_list_account(void);
 
-#endif /* __LIST_ACCOUNT__H__ */
+#endif
