@@ -571,7 +571,7 @@ Account *item;
 
 gint field = GPOINTER_TO_INT(user_data);
 
-	DB( g_printf("(ui_acc_manage_) get %d\n", field) );
+	DB( g_print("(ui_acc_manage_) get %d\n", field) );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -719,9 +719,9 @@ gboolean bool;
 gdouble value;
 Account *item;
 
-	DB( g_printf("\n(ui_acc_manage_getlast)\n") );
+	DB( g_print("\n(ui_acc_manage_getlast)\n") );
 
-	DB( g_printf(" -> for account id=%d\n", data->lastkey) );
+	DB( g_print(" -> for account id=%d\n", data->lastkey) );
 
 	item = da_acc_get(data->lastkey);
 	if(item != NULL)
@@ -785,7 +785,7 @@ GtkTreeIter			 iter;
 
 Account *item;
 
-	DB( g_printf("\n(ui_acc_manage_set)\n") );
+	DB( g_print("\n(ui_acc_manage_set)\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -795,7 +795,7 @@ Account *item;
 	{
 		gtk_tree_model_get(model, &iter, LST_DEFACC_DATAS, &item, -1);
 
-		DB( g_printf(" -> set acc id=%d\n", item->key) );
+		DB( g_print(" -> set acc id=%d\n", item->key) );
 
 
 		gtk_entry_set_text(GTK_ENTRY(data->ST_name), item->name);
@@ -853,17 +853,17 @@ guint32 key;
 //todo: for stock account
 //gboolean is_new;
 
-	DB( g_printf("\n(ui_acc_manage_update)\n") );
+	DB( g_print("\n(ui_acc_manage_update)\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	//window = gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW);
-	//DB( g_printf("(defpayee) widget=%08lx, window=%08lx, inst_data=%08lx\n", treeview, window, data) );
+	//DB( g_print("(defpayee) widget=%08lx, window=%08lx, inst_data=%08lx\n", treeview, window, data) );
 
 	//if true there is a selected node
 	selected = gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), &model, &iter);
 	key = ui_acc_listview_get_selected_key(GTK_TREE_VIEW(data->LV_acc));
 
-	DB( g_printf(" -> selected = %d  action = %d key = %d\n", selected, data->action, key) );
+	DB( g_print(" -> selected = %d  action = %d key = %d\n", selected, data->action, key) );
 
 	//todo amiga/linux
 	/*
@@ -955,7 +955,7 @@ struct ui_acc_manage_data *data;
 Account *item;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-	DB( g_printf("\n(ui_acc_manage_add) (data=%x)\n", (guint)data) );
+	DB( g_print("\n(ui_acc_manage_add) (data=%x)\n", (guint)data) );
 
 	gchar *name = dialog_get_name(_("Account name"), NULL, GTK_WINDOW(data->window));
 	if(name != NULL)
@@ -994,7 +994,7 @@ guint32 key;
 gboolean do_remove;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-	DB( g_printf("\n(ui_acc_manage_remove) (data=%x)\n", (guint)data) );
+	DB( g_print("\n(ui_acc_manage_remove) (data=%x)\n", (guint)data) );
 
 	do_remove = TRUE;
 	key = ui_acc_listview_get_selected_key(GTK_TREE_VIEW(data->LV_acc));
@@ -1036,7 +1036,7 @@ guint32 key;
 gboolean bool;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-	DB( g_printf("\n(ui_acc_manage_rename) (data=%x)\n", (guint)data) );
+	DB( g_print("\n(ui_acc_manage_rename) (data=%x)\n", (guint)data) );
 
 	key = ui_acc_listview_get_selected_key(GTK_TREE_VIEW(data->LV_acc));
 	if( key > 0 )
@@ -1099,7 +1099,7 @@ guint32 i;
 guint32 key;
 gboolean doupdate = FALSE;
 
-	DB( g_printf("\n(ui_acc_manage_cleanup) %x\n", (guint)data) );
+	DB( g_print("\n(ui_acc_manage_cleanup) %x\n", (guint)data) );
 
 		key = ui_acc_listview_get_selected_key(GTK_TREE_VIEW(data->LV_acc));
 		if(key > 0)
@@ -1120,7 +1120,7 @@ gboolean doupdate = FALSE;
 				LST_DEFACC_DATAS, &item,
 				-1);
 
-			DB( g_printf(" -> check acc %d, pos is %d, %s\n", i, item->pos, item->name) );
+			DB( g_print(" -> check acc %d, pos is %d, %s\n", i, item->pos, item->name) );
 
 			if(item->pos != i)
 				data->change++;
@@ -1142,7 +1142,7 @@ gboolean doupdate = FALSE;
 static void ui_acc_manage_setup(struct ui_acc_manage_data *data)
 {
 
-	DB( g_printf("\n(ui_acc_manage_setup)\n") );
+	DB( g_print("\n(ui_acc_manage_setup)\n") );
 
 	//init GList
 	data->tmp_list = NULL; //hb-glist_clone_list(GLOBALS->acc_list, sizeof(struct _Account));
@@ -1183,7 +1183,7 @@ gint row;
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)&data);
-	DB( g_printf("(ui_acc_manage_) window=%x, inst_data=%x\n", (guint)window, (guint)&data) );
+	DB( g_print("(ui_acc_manage_) window=%x, inst_data=%x\n", (guint)window, (guint)&data) );
 
 	//window contents
 	content = gtk_dialog_get_content_area(GTK_DIALOG (window));
